# bqcon
A wrapper that allows to perform basic operations of fetching insertion and updation in google big query. Enabling you to work with datasets and tables using python modules.



Using this package you can perform the following operations in google big query: 


1. Insert 
2. Fetch one 
3. Fetch many 
4. Customquery 
5. Delete Dataset 
6. Detete table 
5. Update  


For Detailed Documenation :  https://iyappan24.github.io/bqcon/


Code Repository :  https://github.com/iyappan24/bqcon

Use Cases and Examples : https://www.iyappanatwork.info/post/python-wrapper-for-google-big-query-bqcon

